# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from flyteidl.datacatalog import datacatalog_pb2 as flyteidl_dot_datacatalog_dot_datacatalog__pb2


class ArtifactsStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/pb.lyft.datacatalog.Artifacts/Get',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetResponse.FromString,
        )
    self.Query = channel.unary_unary(
        '/pb.lyft.datacatalog.Artifacts/Query',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.QueryRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.QueryResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/pb.lyft.datacatalog.Artifacts/Create',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateResponse.FromString,
        )
    self.GenerateProvenance = channel.unary_unary(
        '/pb.lyft.datacatalog.Artifacts/GenerateProvenance',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GenerateProvenanceRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GenerateProvenanceResponse.FromString,
        )


class ArtifactsServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Query(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GenerateProvenance(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ArtifactsServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetResponse.SerializeToString,
      ),
      'Query': grpc.unary_unary_rpc_method_handler(
          servicer.Query,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.QueryRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.QueryResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateResponse.SerializeToString,
      ),
      'GenerateProvenance': grpc.unary_unary_rpc_method_handler(
          servicer.GenerateProvenance,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GenerateProvenanceRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GenerateProvenanceResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'pb.lyft.datacatalog.Artifacts', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/datacatalog/datacatalog.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/datacatalog/datacatalog.proto',
  package='pb.lyft.datacatalog',
  syntax='proto3',
  serialized_options=_b('Z\013datacatalog\220\001\001'),
  serialized_pb=_b('\n&flyteidl/datacatalog/datacatalog.proto\x12\x13pb.lyft.datacatalog\"(\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xda\x01\n\x08\x41rtifact\x12\x12\n\nprovenance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x10\n\x08revision\x18\x04 \x01(\x03\x12\x12\n\ncreated_at\x18\x05 \x01(\x03\x12\x14\n\x0creference_id\x18\x06 \x01(\t\x12.\n\x06inputs\x18\x07 \x03(\x0b\x32\x1e.pb.lyft.datacatalog.Parameter\x12/\n\x07outputs\x18\x08 \x03(\x0b\x32\x1e.pb.lyft.datacatalog.Parameter\"[\n\nArtifactId\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12.\n\x06inputs\x18\x03 \x03(\x0b\x32\x1e.pb.lyft.datacatalog.Parameter\"`\n\nGetRequest\x12\x14\n\nprovenance\x18\x01 \x01(\tH\x00\x12\x36\n\x0b\x61rtifact_id\x18\x02 \x01(\x0b\x32\x1f.pb.lyft.datacatalog.ArtifactIdH\x00\x42\x04\n\x02id\">\n\x0bGetResponse\x12/\n\x08\x61rtifact\x18\x01 \x01(\x0b\x32\x1d.pb.lyft.datacatalog.Artifact\"P\n\tIntFilter\x12\r\n\x05value\x18\x01 \x01(\x03\x12\x34\n\x08operator\x18\x02 \x01(\x0e\x32\".pb.lyft.datacatalog.QueryOperator\"*\n\x0eIntRangeFilter\x12\x0b\n\x03min\x18\x01 \x01(\x03\x12\x0b\n\x03max\x18\x02 \x01(\x03\"|\n\x0bIntQueryKey\x12-\n\x03val\x18\x01 \x01(\x0b\x32\x1e.pb.lyft.datacatalog.IntFilterH\x00\x12\x34\n\x05range\x18\x02 \x01(\x0b\x32#.pb.lyft.datacatalog.IntRangeFilterH\x00\x42\x08\n\x06\x66ilter\"\x8b\x01\n\x0cQueryRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x32\n\x08revision\x18\x03 \x01(\x0b\x32 .pb.lyft.datacatalog.IntQueryKey\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12\x14\n\x0creference_id\x18\x05 \x01(\t\"@\n\rQueryResponse\x12/\n\x08\x61rtifact\x18\x01 \x03(\x0b\x32\x1d.pb.lyft.datacatalog.Artifact\"\x96\x01\n\rCreateRequest\x12,\n\x03ref\x18\x01 \x01(\x0b\x32\x1f.pb.lyft.datacatalog.ArtifactId\x12\x14\n\x0creference_id\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\x03\x12/\n\x07outputs\x18\x04 \x03(\x0b\x32\x1e.pb.lyft.datacatalog.Parameter\"\xa8\x01\n\x0e\x43reateResponse\x12/\n\x08\x61rtifact\x18\x01 \x01(\x0b\x32\x1d.pb.lyft.datacatalog.Artifact\x12:\n\x06status\x18\x02 \x01(\x0e\x32*.pb.lyft.datacatalog.CreateResponse.Status\")\n\x06Status\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\"H\n\x19GenerateProvenanceRequest\x12+\n\x02id\x18\x01 \x01(\x0b\x32\x1f.pb.lyft.datacatalog.ArtifactId\"0\n\x1aGenerateProvenanceResponse\x12\x12\n\nprovenance\x18\x01 \x01(\t*=\n\rQueryOperator\x12\t\n\x05\x45QUAL\x10\x00\x12\x10\n\x0cGREATER_THAN\x10\x01\x12\x0f\n\x0bLESSER_THAN\x10\x02\x32\xf7\x02\n\tArtifacts\x12J\n\x03Get\x12\x1f.pb.lyft.datacatalog.GetRequest\x1a .pb.lyft.datacatalog.GetResponse\"\x00\x12P\n\x05Query\x12!.pb.lyft.datacatalog.QueryRequest\x1a\".pb.lyft.datacatalog.QueryResponse\"\x00\x12S\n\x06\x43reate\x12\".pb.lyft.datacatalog.CreateRequest\x1a#.pb.lyft.datacatalog.CreateResponse\"\x00\x12w\n\x12GenerateProvenance\x12..pb.lyft.datacatalog.GenerateProvenanceRequest\x1a/.pb.lyft.datacatalog.GenerateProvenanceResponse\"\x00\x42\x10Z\x0b\x64\x61tacatalog\x90\x01\x01\x62\x06proto3')
)

_QUERYOPERATOR = _descriptor.EnumDescriptor(
  name='QueryOperator',
  full_name='pb.lyft.datacatalog.QueryOperator',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESSER_THAN', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1489,
  serialized_end=1550,
)
_sym_db.RegisterEnumDescriptor(_QUERYOPERATOR)

QueryOperator = enum_type_wrapper.EnumTypeWrapper(_QUERYOPERATOR)
EQUAL = 0
GREATER_THAN = 1
LESSER_THAN = 2


_CREATERESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='pb.lyft.datacatalog.CreateResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALREADY_EXISTS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1322,
  serialized_end=1363,
)
_sym_db.RegisterEnumDescriptor(_CREATERESPONSE_STATUS)


_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='pb.lyft.datacatalog.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pb.lyft.datacatalog.Parameter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='pb.lyft.datacatalog.Parameter.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=103,
)


_ARTIFACT = _descriptor.Descriptor(
  name='Artifact',
  full_name='pb.lyft.datacatalog.Artifact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='provenance', full_name='pb.lyft.datacatalog.Artifact.provenance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='pb.lyft.datacatalog.Artifact.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='pb.lyft.datacatalog.Artifact.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='pb.lyft.datacatalog.Artifact.revision', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='pb.lyft.datacatalog.Artifact.created_at', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_id', full_name='pb.lyft.datacatalog.Artifact.reference_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='pb.lyft.datacatalog.Artifact.inputs', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='pb.lyft.datacatalog.Artifact.outputs', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=324,
)


_ARTIFACTID = _descriptor.Descriptor(
  name='ArtifactId',
  full_name='pb.lyft.datacatalog.ArtifactId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pb.lyft.datacatalog.ArtifactId.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='pb.lyft.datacatalog.ArtifactId.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='pb.lyft.datacatalog.ArtifactId.inputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=417,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='pb.lyft.datacatalog.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='provenance', full_name='pb.lyft.datacatalog.GetRequest.provenance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='artifact_id', full_name='pb.lyft.datacatalog.GetRequest.artifact_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='pb.lyft.datacatalog.GetRequest.id',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=419,
  serialized_end=515,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='pb.lyft.datacatalog.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifact', full_name='pb.lyft.datacatalog.GetResponse.artifact', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=579,
)


_INTFILTER = _descriptor.Descriptor(
  name='IntFilter',
  full_name='pb.lyft.datacatalog.IntFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='pb.lyft.datacatalog.IntFilter.value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='pb.lyft.datacatalog.IntFilter.operator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=661,
)


_INTRANGEFILTER = _descriptor.Descriptor(
  name='IntRangeFilter',
  full_name='pb.lyft.datacatalog.IntRangeFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='pb.lyft.datacatalog.IntRangeFilter.min', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='pb.lyft.datacatalog.IntRangeFilter.max', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=663,
  serialized_end=705,
)


_INTQUERYKEY = _descriptor.Descriptor(
  name='IntQueryKey',
  full_name='pb.lyft.datacatalog.IntQueryKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='pb.lyft.datacatalog.IntQueryKey.val', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range', full_name='pb.lyft.datacatalog.IntQueryKey.range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='filter', full_name='pb.lyft.datacatalog.IntQueryKey.filter',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=707,
  serialized_end=831,
)


_QUERYREQUEST = _descriptor.Descriptor(
  name='QueryRequest',
  full_name='pb.lyft.datacatalog.QueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pb.lyft.datacatalog.QueryRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='pb.lyft.datacatalog.QueryRequest.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='pb.lyft.datacatalog.QueryRequest.revision', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='pb.lyft.datacatalog.QueryRequest.created_at', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_id', full_name='pb.lyft.datacatalog.QueryRequest.reference_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=973,
)


_QUERYRESPONSE = _descriptor.Descriptor(
  name='QueryResponse',
  full_name='pb.lyft.datacatalog.QueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifact', full_name='pb.lyft.datacatalog.QueryResponse.artifact', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=1039,
)


_CREATEREQUEST = _descriptor.Descriptor(
  name='CreateRequest',
  full_name='pb.lyft.datacatalog.CreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ref', full_name='pb.lyft.datacatalog.CreateRequest.ref', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_id', full_name='pb.lyft.datacatalog.CreateRequest.reference_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='pb.lyft.datacatalog.CreateRequest.revision', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='pb.lyft.datacatalog.CreateRequest.outputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1042,
  serialized_end=1192,
)


_CREATERESPONSE = _descriptor.Descriptor(
  name='CreateResponse',
  full_name='pb.lyft.datacatalog.CreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifact', full_name='pb.lyft.datacatalog.CreateResponse.artifact', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='pb.lyft.datacatalog.CreateResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CREATERESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1195,
  serialized_end=1363,
)


_GENERATEPROVENANCEREQUEST = _descriptor.Descriptor(
  name='GenerateProvenanceRequest',
  full_name='pb.lyft.datacatalog.GenerateProvenanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='pb.lyft.datacatalog.GenerateProvenanceRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1365,
  serialized_end=1437,
)


_GENERATEPROVENANCERESPONSE = _descriptor.Descriptor(
  name='GenerateProvenanceResponse',
  full_name='pb.lyft.datacatalog.GenerateProvenanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='provenance', full_name='pb.lyft.datacatalog.GenerateProvenanceResponse.provenance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1439,
  serialized_end=1487,
)

_ARTIFACT.fields_by_name['inputs'].message_type = _PARAMETER
_ARTIFACT.fields_by_name['outputs'].message_type = _PARAMETER
_ARTIFACTID.fields_by_name['inputs'].message_type = _PARAMETER
_GETREQUEST.fields_by_name['artifact_id'].message_type = _ARTIFACTID
_GETREQUEST.oneofs_by_name['id'].fields.append(
  _GETREQUEST.fields_by_name['provenance'])
_GETREQUEST.fields_by_name['provenance'].containing_oneof = _GETREQUEST.oneofs_by_name['id']
_GETREQUEST.oneofs_by_name['id'].fields.append(
  _GETREQUEST.fields_by_name['artifact_id'])
_GETREQUEST.fields_by_name['artifact_id'].containing_oneof = _GETREQUEST.oneofs_by_name['id']
_GETRESPONSE.fields_by_name['artifact'].message_type = _ARTIFACT
_INTFILTER.fields_by_name['operator'].enum_type = _QUERYOPERATOR
_INTQUERYKEY.fields_by_name['val'].message_type = _INTFILTER
_INTQUERYKEY.fields_by_name['range'].message_type = _INTRANGEFILTER
_INTQUERYKEY.oneofs_by_name['filter'].fields.append(
  _INTQUERYKEY.fields_by_name['val'])
_INTQUERYKEY.fields_by_name['val'].containing_oneof = _INTQUERYKEY.oneofs_by_name['filter']
_INTQUERYKEY.oneofs_by_name['filter'].fields.append(
  _INTQUERYKEY.fields_by_name['range'])
_INTQUERYKEY.fields_by_name['range'].containing_oneof = _INTQUERYKEY.oneofs_by_name['filter']
_QUERYREQUEST.fields_by_name['revision'].message_type = _INTQUERYKEY
_QUERYRESPONSE.fields_by_name['artifact'].message_type = _ARTIFACT
_CREATEREQUEST.fields_by_name['ref'].message_type = _ARTIFACTID
_CREATEREQUEST.fields_by_name['outputs'].message_type = _PARAMETER
_CREATERESPONSE.fields_by_name['artifact'].message_type = _ARTIFACT
_CREATERESPONSE.fields_by_name['status'].enum_type = _CREATERESPONSE_STATUS
_CREATERESPONSE_STATUS.containing_type = _CREATERESPONSE
_GENERATEPROVENANCEREQUEST.fields_by_name['id'].message_type = _ARTIFACTID
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['Artifact'] = _ARTIFACT
DESCRIPTOR.message_types_by_name['ArtifactId'] = _ARTIFACTID
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['IntFilter'] = _INTFILTER
DESCRIPTOR.message_types_by_name['IntRangeFilter'] = _INTRANGEFILTER
DESCRIPTOR.message_types_by_name['IntQueryKey'] = _INTQUERYKEY
DESCRIPTOR.message_types_by_name['QueryRequest'] = _QUERYREQUEST
DESCRIPTOR.message_types_by_name['QueryResponse'] = _QUERYRESPONSE
DESCRIPTOR.message_types_by_name['CreateRequest'] = _CREATEREQUEST
DESCRIPTOR.message_types_by_name['CreateResponse'] = _CREATERESPONSE
DESCRIPTOR.message_types_by_name['GenerateProvenanceRequest'] = _GENERATEPROVENANCEREQUEST
DESCRIPTOR.message_types_by_name['GenerateProvenanceResponse'] = _GENERATEPROVENANCERESPONSE
DESCRIPTOR.enum_types_by_name['QueryOperator'] = _QUERYOPERATOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETER,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.Parameter)
  ))
_sym_db.RegisterMessage(Parameter)

Artifact = _reflection.GeneratedProtocolMessageType('Artifact', (_message.Message,), dict(
  DESCRIPTOR = _ARTIFACT,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.Artifact)
  ))
_sym_db.RegisterMessage(Artifact)

ArtifactId = _reflection.GeneratedProtocolMessageType('ArtifactId', (_message.Message,), dict(
  DESCRIPTOR = _ARTIFACTID,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.ArtifactId)
  ))
_sym_db.RegisterMessage(ArtifactId)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)

IntFilter = _reflection.GeneratedProtocolMessageType('IntFilter', (_message.Message,), dict(
  DESCRIPTOR = _INTFILTER,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.IntFilter)
  ))
_sym_db.RegisterMessage(IntFilter)

IntRangeFilter = _reflection.GeneratedProtocolMessageType('IntRangeFilter', (_message.Message,), dict(
  DESCRIPTOR = _INTRANGEFILTER,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.IntRangeFilter)
  ))
_sym_db.RegisterMessage(IntRangeFilter)

IntQueryKey = _reflection.GeneratedProtocolMessageType('IntQueryKey', (_message.Message,), dict(
  DESCRIPTOR = _INTQUERYKEY,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.IntQueryKey)
  ))
_sym_db.RegisterMessage(IntQueryKey)

QueryRequest = _reflection.GeneratedProtocolMessageType('QueryRequest', (_message.Message,), dict(
  DESCRIPTOR = _QUERYREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.QueryRequest)
  ))
_sym_db.RegisterMessage(QueryRequest)

QueryResponse = _reflection.GeneratedProtocolMessageType('QueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _QUERYRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.QueryResponse)
  ))
_sym_db.RegisterMessage(QueryResponse)

CreateRequest = _reflection.GeneratedProtocolMessageType('CreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.CreateRequest)
  ))
_sym_db.RegisterMessage(CreateRequest)

CreateResponse = _reflection.GeneratedProtocolMessageType('CreateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATERESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.CreateResponse)
  ))
_sym_db.RegisterMessage(CreateResponse)

GenerateProvenanceRequest = _reflection.GeneratedProtocolMessageType('GenerateProvenanceRequest', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEPROVENANCEREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.GenerateProvenanceRequest)
  ))
_sym_db.RegisterMessage(GenerateProvenanceRequest)

GenerateProvenanceResponse = _reflection.GeneratedProtocolMessageType('GenerateProvenanceResponse', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEPROVENANCERESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:pb.lyft.datacatalog.GenerateProvenanceResponse)
  ))
_sym_db.RegisterMessage(GenerateProvenanceResponse)


DESCRIPTOR._options = None

_ARTIFACTS = _descriptor.ServiceDescriptor(
  name='Artifacts',
  full_name='pb.lyft.datacatalog.Artifacts',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1553,
  serialized_end=1928,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='pb.lyft.datacatalog.Artifacts.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Query',
    full_name='pb.lyft.datacatalog.Artifacts.Query',
    index=1,
    containing_service=None,
    input_type=_QUERYREQUEST,
    output_type=_QUERYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='pb.lyft.datacatalog.Artifacts.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEREQUEST,
    output_type=_CREATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateProvenance',
    full_name='pb.lyft.datacatalog.Artifacts.GenerateProvenance',
    index=3,
    containing_service=None,
    input_type=_GENERATEPROVENANCEREQUEST,
    output_type=_GENERATEPROVENANCERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ARTIFACTS)

DESCRIPTOR.services_by_name['Artifacts'] = _ARTIFACTS

Artifacts = service_reflection.GeneratedServiceType('Artifacts', (_service.Service,), dict(
  DESCRIPTOR = _ARTIFACTS,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  ))

Artifacts_Stub = service_reflection.GeneratedServiceStubType('Artifacts_Stub', (Artifacts,), dict(
  DESCRIPTOR = _ARTIFACTS,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  ))


# @@protoc_insertion_point(module_scope)
